# HookNotificationConfig

The configuration for the hook.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**url** | **str** | Applicable to hook notifications only. The webhook URL that Stitch should deliver hook notifications to.  | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


